==> fontforge-20190801-1-x86_64.pkg.tar.xz: usr/include/fontforge/fontforge-version-extras.h <==
/* This is a GENERATED header */

/* Copyright (C) 2019 by FontForge developers */
/*
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.

 * The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef FONTFORGE_VERSION_EXTRAS_H
#define FONTFORGE_VERSION_EXTRAS_H

#include <fontforge-config.h>

/*
  These aren't part of the main config header because they change
  on each configuration invocation
*/

/* git hash that source are built from */
#define FONTFORGE_GIT_VERSION ""

/* Epoch time that configure was run at (no quotes) */
#define FONTFORGE_MODTIME_RAW 1564701157L

/* A user friendly date that that configure was run at: For example 01:48 GMT 6-Sep-2012 */
#define FONTFORGE_MODTIME_STR "23:12 UTC  1-Aug-2019"

#endif /* FONTFORGE_VERSION_EXTRAS_H */

==> fontforge-20190801-2-x86_64.pkg.tar.xz: usr/include/fontforge/fontforge-version-extras.h <==
/* This is a GENERATED header */

/* Copyright (C) 2019 by FontForge developers */
/*
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.

 * The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef FONTFORGE_VERSION_EXTRAS_H
#define FONTFORGE_VERSION_EXTRAS_H

#include <fontforge-config.h>

/*
  These aren't part of the main config header because they change
  on each configuration invocation
*/

/* git hash that source are built from */
#define FONTFORGE_GIT_VERSION ""

/* Epoch time that configure was run at (no quotes) */
#define FONTFORGE_MODTIME_RAW 1572895882L

/* A user friendly date that that configure was run at: For example 01:48 GMT 6-Sep-2012 */
#define FONTFORGE_MODTIME_STR "19:31 UTC  4-Nov-2019"

#endif /* FONTFORGE_VERSION_EXTRAS_H */
